@@ -469,13 +469,13 @@ def load_fbc2_gpr(sbml_model, model):
         fbcrxn = reaction.getPlugin('fbc')
         gpr_assoc = fbcrxn.getGeneProductAssociation()
         if gpr_assoc:
-            gpr = parse_fbc_association(gpr_assoc.getAssociation(), reaction.getId())
+            gpr = parse_fbc_association(gpr_assoc.getAssociation())
             model.set_gpr_association(reaction.getId(), gpr, add_genes=False)
         else:
             model.set_gpr_association(reaction.getId(), None)
 
 
-def parse_fbc_association(gpr_assoc, reaction_id):
+def parse_fbc_association(gpr_assoc):
     gpr = GPRAssociation()
     parsing_error = False
 
@@ -509,9 +509,24 @@ def parse_fbc_association(gpr_assoc, reaction_id):
         parsing_error = True
 
     if parsing_error:
-        warn(f"Gene association for reaction {reaction_id} is not DNF")
-    else:
-        return gpr
+        gpr_str = convert_to_dnf(gpr_assoc)
+        gpr = parse_gpr_rule(gpr_str)
+
+    return gpr
+
+
+def convert_to_dnf(gpr_assoc):
+
+    if gpr_assoc.isFbcOr():
+        tokens = [convert_to_dnf(x) for x in gpr_assoc.getListOfAssociations()]
+        gpr_str = '(' + ' or '.join(tokens) + ')'
+    elif gpr_assoc.isFbcAnd():
+        tokens = [convert_to_dnf(x) for x in gpr_assoc.getListOfAssociations()]
+        gpr_str = '(' + ' and '.join(tokens) + ')'
+    elif gpr_assoc.isGeneProductRef():
+        gpr_str = gpr_assoc.getGeneProduct()
+
+    return gpr_str
 
 
 def extract_metadata(sbml_elem, elem):
